1.0.0 API documentation: GLM_GTX_vector_query

| 1.0.0 API documentation

Functions
GLM_GTX_vector_query
Experimental extensions

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL bool | areCollinear (vec< L, T, Q > const &v0, vec< L, T, Q > const &v1, T const &epsilon)
| Check whether two vectors are collinears. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL bool | areOrthogonal (vec< L, T, Q > const &v0, vec< L, T, Q > const &v1, T const &epsilon)
| Check whether two vectors are orthogonals. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL bool | areOrthonormal (vec< L, T, Q > const &v0, vec< L, T, Q > const &v1, T const &epsilon)
| Check whether two vectors are orthonormal. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, bool, Q > | isCompNull (vec< L, T, Q > const &v, T const &epsilon)
| Check whether a each component of a vector is null. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL bool | isNormalized (vec< L, T, Q > const &v, T const &epsilon)
| Check whether a vector is normalized. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL bool | isNull (vec< L, T, Q > const &v, T const &epsilon)
| Check whether a vector is null. More...

## Detailed Description

Include <glm/gtx/vector_query.hpp> to use the features of this extension.

Query information of vector types

## Function Documentation

## ◆ areCollinear()

GLM_FUNC_DECL bool glm::areCollinear | ( | vec< L, T, Q > const & | v0,
|  | vec< L, T, Q > const & | v1,
|  | T const & | epsilon
| ) |  |

Check whether two vectors are collinears.

See also
  GLM_GTX_vector_query extensions.

## ◆ areOrthogonal()

GLM_FUNC_DECL bool glm::areOrthogonal | ( | vec< L, T, Q > const & | v0,
|  | vec< L, T, Q > const & | v1,
|  | T const & | epsilon
| ) |  |

Check whether two vectors are orthogonals.

See also
  GLM_GTX_vector_query extensions.

## ◆ areOrthonormal()

GLM_FUNC_DECL bool glm::areOrthonormal | ( | vec< L, T, Q > const & | v0,
|  | vec< L, T, Q > const & | v1,
|  | T const & | epsilon
| ) |  |

Check whether two vectors are orthonormal.

See also
  GLM_GTX_vector_query extensions.

## ◆ isCompNull()

GLM_FUNC_DECL vec<L, bool, Q> glm::isCompNull | ( | vec< L, T, Q > const & | v,
|  | T const & | epsilon
| ) |  |

Check whether a each component of a vector is null.

See also
  GLM_GTX_vector_query extensions.

## ◆ isNormalized()

GLM_FUNC_DECL bool glm::isNormalized | ( | vec< L, T, Q > const & | v,
|  | T const & | epsilon
| ) |  |

Check whether a vector is normalized.

See also
  GLM_GTX_vector_query extensions.

## ◆ isNull()

GLM_FUNC_DECL bool glm::isNull | ( | vec< L, T, Q > const & | v,
|  | T const & | epsilon
| ) |  |

Check whether a vector is null.

See also
  GLM_GTX_vector_query extensions.